pub struct StoreWriteBatch { /* private fields */ }Expand description
A physical Store write batch assembled from one or more logical clients.
Use Self::push with the specific prefixed client that produced each
logical key, then Self::commit once to submit all rows in one atomic
Store Put.
Implementations
Sourceimpl StoreWriteBatch
impl StoreWriteBatch
pub fn new() -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn clear(&mut self)
pub fn push( &mut self, client: &StoreClient, key: &Key, value: &[u8], ) -> Result<&mut Self, ClientError>
pub async fn commit(&self, client: &StoreClient) -> Result<u64, ClientError>